@@ -1,8 +1,8 @@
 import json
 import os
+import time
 import zlib
 from abc import ABC
-import time
 
 
 class Message(ABC):
@@ -14,6 +14,7 @@ class Message(ABC):
     >>> message = Message({'key': 'unique-id-1', 'data': 'data'})
     """
 
+    version = 1
     keyname = "key"
 
     def __init__(self, dct, header=None, config=None):
@@ -21,7 +22,11 @@ class Message(ABC):
         self.updated = False
         self.terminated = False
         if header is None:
-            self.header = {}
+            self.header = {
+                "version": self.version,
+                "created": time.time(),
+                "history": [],
+            }
         else:
             self.header = header
         self.dct = dct
@@ -69,10 +74,11 @@ class Message(ABC):
         )
         return parser
 
-    def serialize(self, indent=None):
+    def serialize(self, indent=None, no_compress=False):
         """serialize to binary."""
         data = json.dumps([self.header, self.dct], indent=indent).encode("utf-8")
-        if getattr(self.config, "compress", False) is True:
+
+        if getattr(self.config, "compress", False) is True and no_compress is False:
             return zlib.compress(data)
         else:
             return data
@@ -81,7 +87,7 @@ class Message(ABC):
     def deserialize(cls, raw, config=None):
         """deserialize to json."""
         if raw[0] == ord("{"):
-            header = {}
+            header = None
             content = json.loads(raw)
         elif raw[0] == ord("["):
             data = raw
@@ -92,12 +98,9 @@ class Message(ABC):
         return cls(content, header=header, config=config)
 
     def get_version(self, name):
-        return self.header.setdefault(
-            name,
-            {
-                "version": [],
-            },
-        )
+        for version in self.header["history"]:
+            if version["name"] == name:
+                return version
 
     def get_versions(self):
         return self.header
@@ -111,16 +114,21 @@ class Message(ABC):
 
     def should_update(self, name, version):
         versionDct = self.get_version(name)
-        return version > versionDct["version"]
+        return versionDct is None or version > versionDct["version"]
 
     def update_version(self, name, version):
-        versionDct = self.get_version(name)
-        if version > versionDct["version"]:
-            versionDct["version"] = version
-            versionDct["timestamp"] = time.time()
-            if "order" not in versionDct:
-                versionDct["order"] = len(self.get_versions())
-            self.updated = True
+        self.header["history"].insert(
+            0,
+            {
+                "name": name,
+                "version": version,
+                "receive": time.time(),
+            },
+        )
+        self.updated = True
+
+    def complete(self):
+        self.header["history"][0]["complete"] = time.time()
 
     def terminates(self):
         """ set terminated flag for this message """
@@ -133,6 +141,13 @@ class Message(ABC):
     def update(self, other):
         """ update message content """
         self.dct.update(other)
+        # keep track of updated fields
+        self.header["updated_fields"] = list(other.keys())
+
+    def get_updates(self):
+        """ return a dict containing last updated fields """
+        keys = self.header.get("updated_fields", [])
+        return {k: self.dct[k] for k in keys}
 
     def replace(self, other):
         """ replace message content """
