@@ -155,18 +155,19 @@ class Generator(WorkerCore):
 
     def generate(self):
         """a generator to generate dict."""
-        yield self.options.message(config=self.options)
+        yield {}
 
-    def _step(self):
+    def _step(self, i):
         if not self.generator:
             self.generator = self.generate()
         dct = next(self.generator)
         msg = self.messageClass({}, config=self.options)
         msg.update(dct)
         msg.update_version(self.name, self.version)
-        self.logger.info("Generated %s", msg)
+        self.logger.info("Generated %d-th message %s", i, msg)
         if msg.is_valid():
-            self.logger.info("Writing %s", msg)
+            self.logger.info("Writing %d-th message %s", i, msg)
+            msg.complete()
             msgSize = self.destination.write(msg)
             self.logger.info(f"Message size: {msgSize}")
             self.monitor.record_write(self.destination.topic)
@@ -199,9 +200,11 @@ class Generator(WorkerCore):
         self.monitor.record_start()
 
         try:
+            i = 0
             while True:
+                i += 1
                 self.timer.start()
-                self._step()
+                self._step(i)
                 self.timer.log(self.logger)
         except StopIteration:
             pass
@@ -243,6 +246,8 @@ class Splitter(WorkerCore):
             self.logger.info("Received message '%s'", str(msg))
             self.monitor.record_read(self.source.topic)
 
+            msg.update_version(self.name, self.version)
+
             topic = self.get_topic(msg)
 
             if topic not in self.destinations:
@@ -256,6 +261,7 @@ class Splitter(WorkerCore):
 
             if msg.is_valid():
                 self.logger.info("Writing message %s to topic <%s>", str(msg), topic)
+                msg.complete()
                 msgSize = destination.write(msg)
                 self.logger.info(f"Message size: {msgSize}")
             else:
@@ -393,6 +399,7 @@ class Processor(WorkerCore):
         elif not any((failedOnError, self.has_no_output())):
             if msg.is_valid():
                 self.logger.info("Writing message '%s'", str(msg))
+                msg.complete()
                 msgSize = self.destination.write(msg)
                 self.logger.info(f"Message size: {msgSize}")
                 self.monitor.record_write(self.destination.topic)
